/*
 * imalib
 * 
 * Copyright 2017 Aberystwyth University
 * 
 * This library and program are free software: you can redistribute them
 * and/or modify them under the terms of the GNU General Public License as 
 * published by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 * 
 * The program and library are distributed in the hope that they will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * \file imageLCS.cpp
 * \brief Defines classes to play with LCS images.  Implementation.
 * \author Marek Ososinski <mro7@aber.ac.uk>
 * \copyright 2017 Aberystwyth University
 */

#include "imalib/imageLCS.h"

#include <math.h>

#include <limits>

namespace imalib
{
//-----------------------------------------------------
// Class imageLCS.
//-----------------------------------------------------


   /*!
    * \brief Convert a pixel in the RGB colour space to a pixel in the
    * log-chromaticity space .
    * \param[in] rgb the pixel in RGB colour space.
    * \param[out] lcs The pixel in LCS (must be
    * allocated beforehand).
    */
   void imageLCS::RGBToLCS(const unsigned char* rgb, double* lcs) 
   {
      double r = static_cast<double>(rgb[0]);
      double g = static_cast<double>(rgb[1]);
      double b = static_cast<double>(rgb[2]);

      if (r == 0)
         r = 1;
      if (b == 0)
         b = 1;

      lcs[0] = (g > 0) ? log(r/g) : log(r);
      lcs[1] = (g > 0) ? log(b/g) : log(b);
   }

} // namespace imalib

//  LocalWords:  imageYUV param imageHSV
