/*
 * imalib
 * 
 * Copyright 2017 Aberystwyth University
 * 
 * This library and program are free software: you can redistribute them
 * and/or modify them under the terms of the GNU General Public License as 
 * published by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 * 
 * The program and library are distributed in the hope that they will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * \file imageD3.h
 * \brief A class to serve as a base class for images having 3 doubles per
 * pixel.
 *
 * It's mostly used to create virtual functions for that inheritance tree.
 *
 * \author Fred Labrosse
 * \copyright 2017 Aberystwyth University
 */

#ifndef IMALIB_IMAGED3_H
#define IMALIB_IMAGED3_H

#include <imalib/image.h>

namespace imalib
{
// Forward declaration to avoid the looping dependency if including
// imageRGB.h
class imageRGB;

/*!
 * \class imageD3 imageD3.h imalib/imageD3.h
 * \brief A class to serve as a base class for images having 3 doubles
 * per pixel.
 *
 * It's mostly used to create virtual functions for that inheritance tree.
 */
class imageD3 : public image<double, 3>
{
public:
   /*!
    * \brief Constructor.
    */
   imageD3()
      : image<double,3>()
   {
   }

   /*!
    * \brief Constructor.
    */
   imageD3(short cols, short rows, short tCols = 0, short tRows = 0)
      : image<double,3>(cols, rows, tCols, tRows)
   {
   }

   /*!
    * \brief Copy an imageRGB into the current one.
    * \param[in] image The imageRGB to copy.
    * \todo Change the name to fromRGB for symmetry reasons.
    */
   virtual void copyFromRGB(const imageRGB& image) = 0;

   /*!
    * \brief Copy the image into an imageRGB.
    *
    * The size of the target image is set here in accordance to the source
    * image.
    *
    * \param[out] image The imageRGB.
    */
   virtual void toRGB(imageRGB* image) const = 0;

protected:
private:
};

} // namespace imalib

#endif // IMALIB_IMAGED3_H
