/*
 * imalib
 * 
 * Copyright 2017 Aberystwyth University
 * 
 * This library and program are free software: you can redistribute them
 * and/or modify them under the terms of the GNU General Public License as 
 * published by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 * 
 * The program and library are distributed in the hope that they will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*!
 * \file utilities.cpp
 * \brief A file where several utility functions are defined.
 * Implementation.
 * 
 * \author Fred Labrosse <ffl@aber.ac.uk>
 * \copyright 2017 Aberystwyth University
 */

#include "imalib/utilities.h"

#include <stdlib.h>
#include <math.h>

namespace po = boost::program_options;

namespace imalib
{

po::options_description imalibOptions::imalibOptions_("imalib options");

imalibOptions::imalibOptions()
{
   imalibOptions_.add_options()
   ("verbose,v", po::value<unsigned short>(&(verboseLevel()))->default_value(0),
    "Increases the verbosity level")
   ;
}

/*!
 * \brief Process the command line if an options description is provided.
 * \param[in] vm The boost program_options variable map.
 */
void imalibOptions::commandLine(po::variables_map& vm)
{
   // Nothing needed for now.
}

/*!
 * \brief Computes the sign of the parameter.
 * \param[in] val The value of which we compute the sign.
 * \return -1 if val < 0, 0 if val == 0 and +1 if val > 0.
 */
double sign(double val)
{
   if (val < 0)
      return(-1);
   else if (val > 0)
      return(+1);
   else
      return(0);
}

/*
 * \brief Computes the modulo of a number, even when its value is
 * negative.
 * \param number (IN) The number.
 * \param mod (IN) The divider.
 * \return The new value.
 */
// long modulo(long number, long mod)
//    {
//       long result = number;
//       if (number < 0)
//       {
//          do
//          {
//             result = result + mod;
//          } while (result < 0);
//       }
//       else if (number >= 0)
//       {
//          result = result % mod;
//       }
//
//       return(result);
//    }

} // namespace imalib
